<?php
namespace models;
use Doctrine\Common\Collections\ArrayCollection;

/**
 * Utilisateur
 *
 * @Table(name="utilisateur", uniqueConstraints={@UniqueConstraint(columns={"login","description"})})
 * @Entity (repositoryClass="\models\repositories\UtilisateurRepository")
 */
class Utilisateur
{
	/**
	* L'identifiant unique de l'utilisateur  
	* @var string $id
	*
	* @Column(name="id", type="integer", nullable=false)
	* @Id
	* @GeneratedValue(strategy="IDENTITY");
	*/
	private $id;
	
	/**
	 * Le login sert à l'ouverture de session et est unique
	 * @var string $login
	 *
	 * @Column(name="login", type="string", length=45, nullable=false)
	 */
	private $login;

	/**
	 * Le niveau condition l'accès, 0 pour les administrateurs.
	 * @var integer $level
	 *
	 * @Column(name="level", type="integer", nullable=true)
	 */
	private $level;

	/**
	 * Le mot de passe associé au login
	 * @var string $password
	 *
	 * @Column(name="password", type="string", length=45, nullable=false)
	 */
	private $password;

	/**
	 * La description de l'utilisateur.
	 * @var string $description
	 *
	 * @Column(name="description", type="string", length=128, nullable=false)
	 */
	private $description;

	/**
	 * @OneToMany(targetEntity="Image", mappedBy="utilisateur")
	 */
	private $images;

	/**
	 * Permet de construire un utilisateur. l'identifiant n'est pas fourni, il sera généré par le SGBD.
	 * @param unknown_type $login le login choisi
	 * @param unknown_type $password le mot de passe choisi
	 * @param unknown_type $level le niveau choisi 0 pour un administrateur
	 * @param unknown_type $description la description choisie
	 */
	public function __construct($login,$password, $level, $description){
		
		$this->login = $login;
		$this->level=$level;
		$this->password=$this->encryptPassword($password);
		$this->description=$description;
		$this->images=new ArrayCollection;
	}

	/**
	 * Permet de connaître le login
	 * @return string le login
	 */
	public function getLogin() {
		return $this->login;
	}

	/**
	 * renvoie le mot de passe de l'utilisateur chiffré
	 * @return string le mot de passe chiffré
	 */
	public function getEncryptedPassword() {
		return $this->password;
	}

	/**
	 * Permet de connaïtre le niveau de l'utilisateur
	 * @return number le niveau
	 */
	public function getLevel() {
		return $this->level;
	}

	/**
	 * Permer de connaître la description de l'utilisateur
	 * @return string la description de l'utilisateur
	 */
	public function getDescription() {
		return $this->description;
	}

	/**
	 * Permet de récuperer les images de l'utilisateur
	 * @return \Doctrine\Common\Collections\ArrayCollection les images de l'utilisateur.
	 */
	public function getImages(){
		return  $this->images;
	}

	/**
	 * Permet de modifier le login
	 * @param unknown_type $login le nouveau login
	 */
	public function setLogin($login){
		$this->login=$login;
	}

	/**
	 * Permet de modifier le mot de passe
	 * @param unknown_type $password le nouveau mot de passe
	 */
	public function setPassword($password) {
		$this->password = $this->encryptPassword($password);
	}

	/**
	 * Permet de modifier le niveau de l'utilisateur
	 * @param unknown_type $level le niveau de l'utilisateur
	 */
	public function setLevel($level) {
		$this->level = $level;
	}

	/**
	 * Permet de modifier la description 
	 * @param unknown_type $description la nouvelle description
	 */
	public function setDescription($description) {
		$this->description = $description;
	}

	/**
	 * Renvoie le mot de passe chiffré
	 * @param unknown_type $password le mot de passe à chiffrer
	 * @return unknown le mot de passe chiffré
	 */
	private function encryptPassword($password){
		$CI = & get_instance();
		$CI->load->library('encrypt');
		$encryped= $CI->encrypt->sha1($password);
		return $encryped;
	}
	
	/**
	 * Permet de savoir si le mot de passe passé en paramètre est clui de l'utilisateur
	 * @param unknown_type $password le mot à vérifier
	 * @return boolean true si les mots de passes correspondent et false sinon
	 */
	public function authenticate($password){
		return $this->password===$this->encryptPassword($password);
	}
	
	/**
	 * Renvoie l'identifiant de l'utilisateur courant
	 * @return string l'identidifiant de l'utilisateur courant
	 */
	public function getId(){
		return $this->id;
	}
}